summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/initial_syncer.h
diff options
context:
space:
mode:
authorMatthew Russotto <matthew.russotto@mongodb.com>2020-01-22 19:09:51 +0000
committerevergreen <evergreen@mongodb.com>2020-01-22 19:09:51 +0000
commitc9b6ffbc8de0d865ebd1e9a196cee3516efa12e7 (patch)
tree3aa23a8f53bc861f6539a2246b06e008d5f80dc1 /src/mongo/db/repl/initial_syncer.h
parentd1c386904123e7a200f3a4ee2e33dc21b52e5031 (diff)
downloadmongo-c9b6ffbc8de0d865ebd1e9a196cee3516efa12e7.tar.gz
SERVER-45423 Use isRetriableError instead of isNetworkError for transient errors in initial sync
Diffstat (limited to 'src/mongo/db/repl/initial_syncer.h')
-rw-r--r--src/mongo/db/repl/initial_syncer.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/repl/initial_syncer.h b/src/mongo/db/repl/initial_syncer.h
index 399fdd57c54..54506e384fe 100644
--- a/src/mongo/db/repl/initial_syncer.h
+++ b/src/mongo/db/repl/initial_syncer.h
@@ -596,17 +596,17 @@ private:
const stdx::lock_guard<Latch>& lock, std::shared_ptr<OnCompletionGuard> onCompletionGuard);
/**
* Check if a status is one which means there's a network error and we should retry the current
* operation, and records whether an operation is currently being retried. Note this can only
* handle one operation at a time (i.e. it should not be used in both parts of the "split"
* section of Initial Sync)
*/
- bool _shouldRetryNetworkError(WithLock lk, Status status);
+ bool _shouldRetryError(WithLock lk, Status status);
/**
* Indicates we are no longer handling a network error.
*/
- void _clearNetworkError(WithLock lk);
+ void _clearRetriableError(WithLock lk);
/**
* Checks the given status (or embedded status inside the callback args) and current data
@@ -596,17 +596,17 @@ private:
const stdx::lock_guard<Latch>& lock, std::shared_ptr<OnCompletionGuard> onCompletionGuard);
/**
- * Check if a status is one which means there's a network error and we should retry the current
- * operation, and records whether an operation is currently being retried. Note this can only
- * handle one operation at a time (i.e. it should not be used in both parts of the "split"
- * section of Initial Sync)
+ * Check if a status is one which means there's a retriable error and we should retry the
+ * current operation, and records whether an operation is currently being retried. Note this
+ * can only handle one operation at a time (i.e. it should not be used in both parts of the
+ * "split" section of Initial Sync)
*/
@@ -596,17 +596,17 @@ private:
/**
- * Indicates we are no longer handling a network error.
+ * Indicates we are no longer handling a retriable error.
*/